Reader and writer for PO files
==============================

The Uniforum PO (portable object) format is a human-readable format for
localization data used by the gettext tools.  The po module implements
classes to read and write PO files.
